lbsntransform package is maintained by Alexander Dunkel and [vgiscience.org](https://vgiscience.org)

Found any errors or bugs? Please email me alexander.dunkel[ät]tu-dresden.de

lbsntransform docs built with [mkdocs](https://github.com/mkdocs/mkdocs) and [ReadTheDocs theme](https://github.com/mkdocs/mkdocs/tree/master/mkdocs/themes/readthedocs).

lbsntransform is developed under open source GNU GPLv3 License.